@@ -1,6 +1,6 @@
 #' @export
 format.describe_posterior <- function(x,
-                                      cp,
+                                      cp = NULL,
                                       digits = 2,
                                       format = "text",
                                       ci_string = "CI",
@@ -14,11 +14,16 @@ format.describe_posterior <- function(x,
     attributes(x) <- utils::modifyList(att, attributes(x))
   }
 
+  # validation check
+  if (is.null(digits)) {
+    digits <- 2
+  }
+
   # format columns and values of data frame
   out <- insight::format_table(x, digits = digits, format = format, ...)
 
   # different CI-types as column names?
-  if (ci_string != "CI" && any(grepl("CI$", colnames(out)))) {
+  if (ci_string != "CI" && any(endsWith(colnames(out), "CI"))) {
     colnames(out) <- gsub("(.*)CI$", paste0("\\1", ci_string), colnames(out))
   }
 
@@ -68,6 +73,11 @@ format.bayestestR_eti <- format.describe_posterior
 #' @export
 format.bayestestR_si <- format.describe_posterior
 
+#' @export
+format.equivalence_test <- format.describe_posterior
+
+#' @export
+format.rope <- format.describe_posterior
 
 
 
@@ -172,9 +182,9 @@ format.bayesfactor_inclusion <- function(x,
   # footer
   if (is.null(format) || format == "text") {
     footer <- list(
-      c("\n* Compared among: "),
+      "\n* Compared among: ",
       c(if (matched) "matched models only" else "all models", "cyan"),
-      c("\n*    Priors odds: "),
+      "\n*    Priors odds: ",
       c(if (!is.null(priorOdds)) "custom" else "uniform-equal", "cyan"),
       if (log) c("\n\nBayes Factors are on the log-scale.", "red")
     )
@@ -220,7 +230,7 @@ format.bayesfactor_restricted <- function(x,
   # footer
   if (is.null(format) || format == "text") {
     footer <- list(
-      c("\n* Bayes factors for the restricted model vs. the un-restricted model.\n"),
+      "\n* Bayes factors for the restricted model vs. the un-restricted model.\n",
       if (log) c("\nBayes Factors are on the log-scale.\n", "red")
     )
     # color formatting for caption
@@ -287,17 +297,18 @@ format.bayesfactor_parameters <- function(x,
   # footer
   if (is.null(format) || format == "text") {
     footer <- list(
-      c("\n* Evidence Against The Null: "),
-      c(null, "cyan"),
-      if (direction) c("\n*                 Direction: "),
+      "\n* Evidence Against The Null: ",
+      c(paste0(null, "\n"), "cyan"),
+      if (direction) "*                 Direction: ",
       if (direction < 0) c("Left-Sided test", "cyan"),
       if (direction > 0) c("Right-Sided test", "cyan"),
+      if (direction) "\n",
       if (log) c("\n\nBayes Factors are on the log-scale.\n", "red")
     )
   } else {
     footer <- insight::compact_list(list(
       paste0("Evidence Against The Null: ", null),
-      if (direction) c("Direction: "),
+      if (direction) "Direction: ",
       if (direction < 0) "Left-Sided test",
       if (direction > 0) "Right-Sided test",
       if (log) "Bayes Factors are on the log-scale."
