@@ -4,12 +4,13 @@
 #' the goal of this function is to un-update the posteriors to obtain models
 #' representing the priors. These models can then be used to examine the prior
 #' predictive distribution, or to compare priors with posteriors.
-#' \cr\cr
+#'
 #' This function in used internally to compute Bayes factors.
 #'
 #' @param model A fitted Bayesian model.
 #' @param verbose Toggle warnings.
-#' @param newdata List of `data.frames` to update the model with new data. Required even if the original data should be used.
+#' @param newdata List of `data.frames` to update the model with new data.
+#' Required even if the original data should be used.
 #' @param ... Not used
 #'
 #' @return A model un-fitted to the data, representing the prior model.
@@ -33,15 +34,13 @@ unupdate.stanreg <- function(model, verbose = TRUE, ...) {
   }
 
   if (verbose) {
-    message("Sampling priors, please wait...")
+    insight::format_alert("Sampling priors, please wait...")
   }
 
   prior_dists <- sapply(rstanarm::prior_summary(model), `[[`, "dist")
   if (anyNA(prior_dists)) {
-    stop(
-      "Cannot sample from flat priors (such as when priors are ",
-      "set to 'NULL' in a 'stanreg' model).",
-      call. = FALSE
+    insight::format_error(
+      "Cannot sample from flat priors (such as when priors are set to 'NULL' in a 'stanreg' model)."
     )
   }
 
@@ -64,24 +63,22 @@ unupdate.brmsfit <- function(model, verbose = TRUE, ...) {
   }
 
   if (verbose) {
-    message("Sampling priors, please wait...")
+    insight::format_alert("Sampling priors, please wait...")
   }
 
-  utils::capture.output(
+  utils::capture.output({
     model_prior <- try(suppressMessages(suppressWarnings(
       stats::update(model, sample_prior = "only", refresh = 0)
     )), silent = TRUE)
-  )
+  })
 
   if (methods::is(model_prior, "try-error")) {
-    if (grepl("proper priors", model_prior)) {
-      stop(
-        "Cannot sample from flat priors (such as the default ",
-        "priors for fixed-effects in a 'brmsfit' model).",
-        call. = FALSE
+    if (grepl("proper priors", model_prior, fixed = TRUE)) {
+      insight::format_error(
+        "Cannot sample from flat priors (such as the default priors for fixed-effects in a 'brmsfit' model)."
       )
     } else {
-      stop(model_prior, call. = FALSE)
+      insight::format_error(model_prior)
     }
   }
 
@@ -102,28 +99,28 @@ unupdate.brmsfit_multiple <- function(model,
   }
 
   if (verbose) {
-    message("Sampling priors, please wait...")
+    insight::format_alert("Sampling priors, please wait...")
   }
 
-  utils::capture.output(model_prior <-
-    try(suppressMessages(suppressWarnings(
-      stats::update(
-        model,
-        sample_prior = "only",
-        newdata = newdata,
-        refresh = 0
-      )
-    )), silent = TRUE))
+  utils::capture.output({
+    model_prior <-
+      try(suppressMessages(suppressWarnings(
+        stats::update(
+          model,
+          sample_prior = "only",
+          newdata = newdata,
+          refresh = 0
+        )
+      )), silent = TRUE)
+  })
 
   if (methods::is(model_prior, "try-error")) {
-    if (grepl("proper priors", model_prior)) {
-      stop(
-        "Cannot sample from flat priors (such as the default ",
-        "priors for fixed-effects in a 'brmsfit' model).",
-        call. = FALSE
+    if (grepl("proper priors", model_prior, fixed = TRUE)) {
+      insight::format_error(
+        "Cannot sample from flat priors (such as the default priors for fixed-effects in a 'brmsfit' model)."
       )
     } else {
-      stop(model_prior, call. = FALSE)
+      insight::format_error(model_prior)
     }
   }
 
@@ -142,12 +139,14 @@ unupdate.blavaan <- function(model, verbose = TRUE, ...) {
   }
 
   if (verbose) {
-    message("Sampling priors, please wait...")
+    insight::format_alert("Sampling priors, please wait...")
   }
 
   cl$prisamp <- TRUE
   suppressMessages(suppressWarnings(
-    utils::capture.output(model_prior <- eval(cl))
+    utils::capture.output({
+      model_prior <- eval(cl)
+    })
   ))
 
   model_prior
