@@ -1,6 +1,8 @@
+skip_on_os(os = "mac")
+
 test_that("check_prior - stanreg", {
   skip_on_cran()
-  skip_on_os(os = "windows")
+  skip_on_os(os = c("windows", "mac"))
   skip_if_offline()
   skip_if_not_or_load_if_installed("rstanarm")
   skip_if_not_or_load_if_installed("BH")
@@ -10,12 +12,12 @@ test_that("check_prior - stanreg", {
   set.seed(333)
   model1 <- insight::download_model("stanreg_lm_1")
 
-  expect_equal(
+  expect_identical(
     check_prior(model1)$Prior_Quality,
     c("informative", "uninformative")
   )
 
-  expect_equal(
+  expect_identical(
     check_prior(model1, method = "lakeland")$Prior_Quality,
     c("informative", "informative")
   )
@@ -43,7 +45,7 @@ test_that("check_prior - brms (linux)", {
     )
   })
 
-  expect_warning(expect_equal(
+  expect_warning(expect_identical(
     check_prior(model2)$Prior_Quality,
     c(
       "uninformative", "informative", "informative", "uninformative",
@@ -51,7 +53,7 @@ test_that("check_prior - brms (linux)", {
     )
   ))
 
-  expect_warning(expect_equal(
+  expect_warning(expect_identical(
     check_prior(model2, method = "lakeland")$Prior_Quality,
     c(
       "informative", "informative", "informative", "informative",
@@ -78,20 +80,19 @@ test_that("check_prior - brms (linux)", {
     chains = 2, silent = TRUE, refresh = 0
   )
 
-  # TODO: check hard-coded values")
-  # expect_warning(expect_equal(
-  #   check_prior(model2)$Prior_Quality,
-  #   c(
-  #     "uninformative", "informative", "informative", "uninformative",
-  #     "uninformative", "not determinable", "not determinable", "not determinable"
-  #   )
-  # ))
+  # TODO: check hard-coded values
+  expect_warning(expect_identical(
+    check_prior(model2)$Prior_Quality,
+    c(
+      "uninformative", "informative", "informative", "uninformative",
+      "uninformative", "not determinable", "not determinable", "not determinable"
+    )
+  ))
 
-
-  expect_warning(expect_equal(
+  expect_warning(expect_identical(
     check_prior(model2, method = "lakeland")$Prior_Quality,
     c(
-      "informative", "informative", "informative", "informative",
+      "informative", "misinformative", "informative", "informative",
       "informative", "not determinable", "not determinable", "not determinable"
     )
   ))
@@ -99,7 +100,7 @@ test_that("check_prior - brms (linux)", {
 
 test_that("check_prior - brms (not linux or windows)", {
   skip_on_cran()
-  skip_on_os(os = c("linux", "windows"))
+  skip_on_os(os = c("linux", "windows", "mac"))
   skip_if_offline()
   skip_if_not_or_load_if_installed("rstanarm")
   skip_if_not_or_load_if_installed("BH")
@@ -117,7 +118,7 @@ test_that("check_prior - brms (not linux or windows)", {
     )
   })
 
-  expect_warning(expect_equal(
+  expect_warning(expect_identical(
     check_prior(model2)$Prior_Quality,
     c(
       "uninformative", "uninformative", "informative", "uninformative",
@@ -125,7 +126,7 @@ test_that("check_prior - brms (not linux or windows)", {
     )
   ))
 
-  expect_warning(expect_equal(
+  expect_warning(expect_identical(
     check_prior(model2, method = "lakeland")$Prior_Quality,
     c(
       "informative", "informative", "informative", "informative",
