@@ -6,18 +6,17 @@ test_that("hdi", {
   skip_if_not_or_load_if_installed("httr")
   skip_if_not_or_load_if_installed("BayesFactor")
 
-  expect_equal(hdi(distribution_normal(1000), ci = .90)$CI_low[1], -1.64, tolerance = 0.02)
-  expect_equal(nrow(hdi(distribution_normal(1000), ci = c(.80, .90, .95))), 3, tolerance = 0.01)
+  expect_equal(hdi(distribution_normal(1000), ci = 0.90)$CI_low[1], -1.64, tolerance = 0.02)
+  expect_equal(nrow(hdi(distribution_normal(1000), ci = c(0.80, 0.90, 0.95))), 3, tolerance = 0.01)
   expect_equal(hdi(distribution_normal(1000), ci = 1)$CI_low[1], -3.29, tolerance = 0.02)
-  expect_equal(nchar(capture.output(print(hdi(distribution_normal(1000))))), 22)
-  expect_equal(length(capture.output(print(hdi(distribution_normal(1000), ci = c(.80, .90))))), 5)
+  expect_identical(nchar(capture.output(print(hdi(distribution_normal(1000))))), 22L)
+  expect_length(capture.output(print(hdi(distribution_normal(1000), ci = c(0.80, 0.90)))), 5)
 
-
-  expect_warning(hdi(c(2, 3, NA)))
+  expect_message(hdi(c(2, 3, NA)))
   expect_warning(hdi(c(2, 3)))
-  expect_warning(hdi(distribution_normal(1000), ci = 0.0000001))
+  expect_message(hdi(distribution_normal(1000), ci = 0.0000001))
   expect_warning(hdi(distribution_normal(1000), ci = 950))
-  expect_warning(hdi(c(0, 0, 0)))
+  expect_message(hdi(c(0, 0, 0)))
 })
 
 
@@ -65,7 +64,7 @@ test_that("ci - BayesFactor", {
   skip_if_not_or_load_if_installed("httr")
   skip_if_not_or_load_if_installed("BayesFactor")
 
-  mod_bf <- proportionBF(y = 15, N = 25, p = .5)
+  mod_bf <- proportionBF(y = 15, N = 25, p = 0.5)
   p_bf <- insight::get_parameters(mod_bf)
 
   expect_equal(
